package solutions.bitbadger.documents.jvm.integration.sqlite

import org.junit.jupiter.api.DisplayName
import org.junit.jupiter.api.assertThrows
import solutions.bitbadger.documents.DocumentException
import solutions.bitbadger.documents.jvm.integration.common.Definition
import kotlin.test.Test

/**
 * SQLite integration tests for the `Definition` object / `ensure*` connection extension functions
 */
@DisplayName("Java | Kotlin | SQLite: Definition")
class DefinitionIT {

    @Test
    @DisplayName("ensureTable creates table and index")
    fun ensureTable() =
        SQLiteDB().use(Definition::ensureTable)

    @Test
    @DisplayName("ensureFieldIndex creates an index")
    fun ensureFieldIndex() =
        SQLiteDB().use(Definition::ensureFieldIndex)

    @Test
    @DisplayName("ensureDocumentIndex fails for full index")
    fun ensureDocumentIndexFull() {
        assertThrows<DocumentException> { SQLiteDB().use(Definition::ensureDocumentIndexFull) }
    }

    @Test
    @DisplayName("ensureDocumentIndex fails for optimized index")
    fun ensureDocumentIndexOptimized() {
        assertThrows<DocumentException> { SQLiteDB().use(Definition::ensureDocumentIndexOptimized) }
    }
}
